@@ -21,7 +21,7 @@
    Originally written by Wayne Davison <davison@borland.com>.  */
 
 #include "system.h"
-#include "getopt.h"
+#include <getopt.h>
 #include <string.h>
 
 /* FIXME: Programs should not have such limits.  */
@@ -340,7 +340,7 @@ main (int argc, char *const *argv)
 
   /* Decode command options.  */
 
-  while (option_char = getopt_long (argc, argv, "=ceopPsUu",
+  while (option_char = getopt_long (argc, (char **) argv, "=ceopPsUu",
 				    long_options, NULL),
 	 option_char != EOF)
     switch (option_char)
