@@ -87,7 +87,7 @@ const char *tgetstr ();
 # include <unistd.h>
 #endif
 
-#include "getopt.h"
+#include <getopt.h>
 
 char *getenv ();
 FILE *readpipe PARAMS ((const char *, ...));
@@ -1185,13 +1185,15 @@ Mandatory arguments to long options are mandatory for short options too.\n\
   -K, --no-init-term         like -t, but no termcap init/term strings\n\
   -1, --no-deleted           inhibit output of deleted words\n\
   -2, --no-inserted          inhibit output of inserted words\n\
-  -3, --no-common            inhibit output of common words\n\
+  -3, --no-common            inhibit output of common words\n"));
+      printf (_("\
   -a, --auto-pager           automatically calls a pager\n\
   -h, --help                 print this help\n\
   -i, --ignore-case          fold character case while comparing\n\
   -l, --less-mode            variation of printer mode for \"less\"\n\
   -n, --avoid-wraps          do not extend fields through newlines\n\
-  -p, --printer              overstrike as for printers\n\
+  -p, --printer              overstrike as for printers\n"));
+      printf (_("\
   -s, --statistics           say how many words deleted, inserted etc.\n\
   -t, --terminal             use termcap as for terminal displays\n\
   -v, --version              print program version then exit\n\
@@ -1252,8 +1254,8 @@ main (int argc, char *const argv[])
   count_changed_left = 0;
   count_changed_right = 0;
 
-  while (option_char = getopt_long (argc, argv, "123CKahilnpstvw:x:y:z:",
-				    longopts, NULL),
+  while (option_char = getopt_long (argc, (char **) argv,
+				    "123CKahilnpstvw:x:y:z:", longopts, NULL),
 	 option_char != EOF)
     switch (option_char)
       {
