@@ -27,7 +27,7 @@
 #undef EXIT_FAILURE
 #define EXIT_FAILURE 2		/* any other reason for exit */
 
-#include "getopt.h"
+#include <getopt.h>
 
 const char *program_name;	/* name of executing program */
 
@@ -193,14 +193,20 @@ Mandatory arguments to long options are mandatory for short options too.\n\
   -K, --no-init-term         like -t, but no termcap init/term strings\n\
   -1, --no-deleted           inhibit output of deleted words\n\
   -2, --no-inserted          inhibit output of inserted words\n\
-  -3, --no-common            inhibit output of common words\n\
+  -3, --no-common            inhibit output of common words\n"),
+	     stdout);
+      fputs (_("\
   -a, --auto-pager           automatically calls a pager\n\
   -h, --help                 print this help\n\
   -i, --ignore-case          fold character case while comparing\n\
   -l, --less-mode            variation of printer mode for \"less\"\n\
   -n, --avoid-wraps          do not extend fields through newlines\n\
-  -p, --printer              overstrike as for printers\n\
-  -q, --quiet                inhibit the `mdiff' call message\n\
+  -p, --printer              overstrike as for printers\n"),
+	     stdout);
+      fputs (_("\
+  -q, --quiet                inhibit the `mdiff' call message\n"),
+	     stdout);
+      fputs (_("\
   -s, --statistics           say how many words deleted, inserted etc.\n\
   -t, --terminal             use termcap as for terminal displays\n\
   -v, --version              print program version then exit\n\
@@ -238,8 +244,9 @@ main (int argc, char *const argv[])
 
   /* Decode arguments.  */
 
-  while (option_char = getopt_long (argc, argv, "123CKachidlnpqstvw:x:y:z:",
-				    longopts, NULL),
+  while (option_char = getopt_long (argc, (char **) argv,
+				    "123CKachidlnpqstvw:x:y:z:", longopts,
+				    NULL),
 	 option_char != EOF)
     switch (option_char)
       {
@@ -333,10 +340,11 @@ main (int argc, char *const argv[])
     {
       int counter;
 
+      /* TRANSLATORS: This and the next string are one message. */
       fprintf (stderr, _("Launching `%s"), MDIFF_PROGRAM);
       for (counter = 1; counter < arguments; counter++)
 	fprintf (stderr, " %s", argument_list[counter]);
-      fprintf (stderr, "'\n");
+      fprintf (stderr, _("'\n"));
     }
 
   add_argument (NULL);
